@@ -14,16 +14,25 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+"""The ActionChains implementation."""
 
-"""The ActionChains implementation,"""
-import warnings
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Union
 
 from selenium.webdriver.remote.webelement import WebElement
 
 from .actions.action_builder import ActionBuilder
-from .actions.wheel_input import ScrollOrigin
+from .actions.key_input import KeyInput
+from .actions.pointer_input import PointerInput
+from .actions.wheel_input import ScrollOrigin, WheelInput
 from .utils import keys_to_typing
 
+if TYPE_CHECKING:
+    from selenium.webdriver.remote.webdriver import WebDriver
+
+AnyDevice = Union[PointerInput, KeyInput, WheelInput]
+
 
 class ActionChains:
     """ActionChains are a way to automate low level interactions such as mouse
@@ -58,7 +67,7 @@ class ActionChains:
     another.
     """
 
-    def __init__(self, driver, duration=250):
+    def __init__(self, driver: WebDriver, duration: int = 250, devices: list[AnyDevice] | None = None) -> None:
         """Creates a new ActionChains.
 
         :Args:
@@ -66,20 +75,31 @@ class ActionChains:
          - duration: override the default 250 msecs of DEFAULT_MOVE_DURATION in PointerInput
         """
         self._driver = driver
-        self.w3c_actions = ActionBuilder(driver, duration=duration)
+        mouse = None
+        keyboard = None
+        wheel = None
+        if devices is not None and isinstance(devices, list):
+            for device in devices:
+                if isinstance(device, PointerInput):
+                    mouse = device
+                if isinstance(device, KeyInput):
+                    keyboard = device
+                if isinstance(device, WheelInput):
+                    wheel = device
+        self.w3c_actions = ActionBuilder(driver, mouse=mouse, keyboard=keyboard, wheel=wheel, duration=duration)
 
-    def perform(self):
+    def perform(self) -> None:
         """Performs all stored actions."""
         self.w3c_actions.perform()
 
-    def reset_actions(self):
+    def reset_actions(self) -> None:
         """Clears actions that are already stored locally and on the remote
         end."""
         self.w3c_actions.clear_actions()
         for device in self.w3c_actions.devices:
             device.clear_actions()
 
-    def click(self, on_element=None):
+    def click(self, on_element: WebElement | None = None) -> ActionChains:
         """Clicks an element.
 
         :Args:
@@ -95,7 +115,7 @@ class ActionChains:
 
         return self
 
-    def click_and_hold(self, on_element=None):
+    def click_and_hold(self, on_element: WebElement | None = None) -> ActionChains:
         """Holds down the left mouse button on an element.
 
         :Args:
@@ -110,7 +130,7 @@ class ActionChains:
 
         return self
 
-    def context_click(self, on_element=None):
+    def context_click(self, on_element: WebElement | None = None) -> ActionChains:
         """Performs a context-click (right click) on an element.
 
         :Args:
@@ -126,7 +146,7 @@ class ActionChains:
 
         return self
 
-    def double_click(self, on_element=None):
+    def double_click(self, on_element: WebElement | None = None) -> ActionChains:
         """Double-clicks an element.
 
         :Args:
@@ -142,7 +162,7 @@ class ActionChains:
 
         return self
 
-    def drag_and_drop(self, source, target):
+    def drag_and_drop(self, source: WebElement, target: WebElement) -> ActionChains:
         """Holds down the left mouse button on the source element, then moves
         to the target element and releases the mouse button.
 
@@ -154,7 +174,7 @@ class ActionChains:
         self.release(target)
         return self
 
-    def drag_and_drop_by_offset(self, source, xoffset, yoffset):
+    def drag_and_drop_by_offset(self, source: WebElement, xoffset: int, yoffset: int) -> ActionChains:
         """Holds down the left mouse button on the source element, then moves
         to the target offset and releases the mouse button.
 
@@ -168,7 +188,7 @@ class ActionChains:
         self.release()
         return self
 
-    def key_down(self, value, element=None):
+    def key_down(self, value: str, element: WebElement | None = None) -> ActionChains:
         """Sends a key press only, without releasing it. Should only be used
         with modifier keys (Control, Alt and Shift).
 
@@ -179,7 +199,7 @@ class ActionChains:
 
         Example, pressing ctrl+c::
 
-            ActionChains(driver).key_down(Keys.CONTROL).send_keys('c').key_up(Keys.CONTROL).perform()
+            ActionChains(driver).key_down(Keys.CONTROL).send_keys("c").key_up(Keys.CONTROL).perform()
         """
         if element:
             self.click(element)
@@ -189,7 +209,7 @@ class ActionChains:
 
         return self
 
-    def key_up(self, value, element=None):
+    def key_up(self, value: str, element: WebElement | None = None) -> ActionChains:
         """Releases a modifier key.
 
         :Args:
@@ -199,7 +219,7 @@ class ActionChains:
 
         Example, pressing ctrl+c::
 
-            ActionChains(driver).key_down(Keys.CONTROL).send_keys('c').key_up(Keys.CONTROL).perform()
+            ActionChains(driver).key_down(Keys.CONTROL).send_keys("c").key_up(Keys.CONTROL).perform()
         """
         if element:
             self.click(element)
@@ -209,7 +229,7 @@ class ActionChains:
 
         return self
 
-    def move_by_offset(self, xoffset, yoffset):
+    def move_by_offset(self, xoffset: int, yoffset: int) -> ActionChains:
         """Moving the mouse to an offset from current mouse position.
 
         :Args:
@@ -222,7 +242,7 @@ class ActionChains:
 
         return self
 
-    def move_to_element(self, to_element):
+    def move_to_element(self, to_element: WebElement) -> ActionChains:
         """Moving the mouse to the middle of an element.
 
         :Args:
@@ -234,7 +254,7 @@ class ActionChains:
 
         return self
 
-    def move_to_element_with_offset(self, to_element, xoffset, yoffset):
+    def move_to_element_with_offset(self, to_element: WebElement, xoffset: int, yoffset: int) -> ActionChains:
         """Move the mouse by an offset of the specified element. Offsets are
         relative to the in-view center point of the element.
 
@@ -249,7 +269,7 @@ class ActionChains:
 
         return self
 
-    def pause(self, seconds):
+    def pause(self, seconds: float | int) -> ActionChains:
         """Pause all inputs for the specified duration in seconds."""
 
         self.w3c_actions.pointer_action.pause(seconds)
@@ -257,7 +277,7 @@ class ActionChains:
 
         return self
 
-    def release(self, on_element=None):
+    def release(self, on_element: WebElement | None = None) -> ActionChains:
         """Releasing a held mouse button on an element.
 
         :Args:
@@ -272,7 +292,7 @@ class ActionChains:
 
         return self
 
-    def send_keys(self, *keys_to_send):
+    def send_keys(self, *keys_to_send: str) -> ActionChains:
         """Sends keys to current focused element.
 
         :Args:
@@ -287,7 +307,7 @@ class ActionChains:
 
         return self
 
-    def send_keys_to_element(self, element, *keys_to_send):
+    def send_keys_to_element(self, element: WebElement, *keys_to_send: str) -> ActionChains:
         """Sends keys to an element.
 
         :Args:
@@ -299,7 +319,7 @@ class ActionChains:
         self.send_keys(*keys_to_send)
         return self
 
-    def scroll_to_element(self, element: WebElement):
+    def scroll_to_element(self, element: WebElement) -> ActionChains:
         """If the element is outside the viewport, scrolls the bottom of the
         element to the bottom of the viewport.
 
@@ -310,7 +330,7 @@ class ActionChains:
         self.w3c_actions.wheel_action.scroll(origin=element)
         return self
 
-    def scroll_by_amount(self, delta_x: int, delta_y: int):
+    def scroll_by_amount(self, delta_x: int, delta_y: int) -> ActionChains:
         """Scrolls by provided amounts with the origin in the top left corner
         of the viewport.
 
@@ -322,7 +342,7 @@ class ActionChains:
         self.w3c_actions.wheel_action.scroll(delta_x=delta_x, delta_y=delta_y)
         return self
 
-    def scroll_from_origin(self, scroll_origin: ScrollOrigin, delta_x: int, delta_y: int):
+    def scroll_from_origin(self, scroll_origin: ScrollOrigin, delta_x: int, delta_y: int) -> ActionChains:
         """Scrolls by provided amount based on a provided origin. The scroll
         origin is either the center of an element or the upper left of the
         viewport plus any offsets. If the origin is an element, and the element
@@ -350,30 +370,10 @@ class ActionChains:
         )
         return self
 
-    def scroll(self, x: int, y: int, delta_x: int, delta_y: int, duration: int = 0, origin: str = "viewport"):
-        """Sends wheel scroll information to the browser to be processed.
-
-        :Args:
-         - x: starting X coordinate
-         - y: starting Y coordinate
-         - delta_x: the distance the mouse will scroll on the x axis
-         - delta_y: the distance the mouse will scroll on the y axis
-        """
-        warnings.warn(
-            "scroll() has been deprecated, please use scroll_to_element(), scroll_by_amount() or scroll_from_origin().",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
-        self.w3c_actions.wheel_action.scroll(
-            x=x, y=y, delta_x=delta_x, delta_y=delta_y, duration=duration, origin=origin
-        )
-        return self
-
     # Context manager so ActionChains can be used in a 'with .. as' statements.
 
-    def __enter__(self):
+    def __enter__(self) -> ActionChains:
         return self  # Return created instance of self.
 
-    def __exit__(self, _type, _value, _traceback):
+    def __exit__(self, _type, _value, _traceback) -> None:
         pass  # Do nothing, does not require additional cleanup.
