@@ -20,8 +20,9 @@ import os
 import platform
 import subprocess
 import sys
+import sysconfig
 from pathlib import Path
-from typing import List
+from typing import List, Optional
 
 from selenium.common import WebDriverException
 
@@ -61,9 +62,18 @@ class SeleniumManager:
         :Raises: WebDriverException if the platform is unsupported
         """
 
-        if (path := os.getenv("SE_MANAGER_PATH")) is not None:
-            logger.debug("Selenium Manager set by env SE_MANAGER_PATH to: %s", path)
-            path = Path(path)
+        compiled_path = Path(__file__).parent.joinpath("selenium-manager")
+        exe = sysconfig.get_config_var("EXE")
+        if exe is not None:
+            compiled_path = compiled_path.with_suffix(exe)
+
+        path: Optional[Path] = None
+
+        if (env_path := os.getenv("SE_MANAGER_PATH")) is not None:
+            logger.debug("Selenium Manager set by env SE_MANAGER_PATH to: %s", env_path)
+            path = Path(env_path)
+        elif compiled_path.exists():
+            path = compiled_path
         else:
             allowed = {
                 ("darwin", "any"): "macos/selenium-manager",
@@ -84,7 +94,7 @@ class SeleniumManager:
 
             path = Path(__file__).parent.joinpath(location)
 
-        if not path.is_file():
+        if path is None or not path.is_file():
             raise WebDriverException(f"Unable to obtain working Selenium Manager binary; {path}")
 
         logger.debug("Selenium Manager binary found at: %s", path)
