@@ -18,19 +18,12 @@ import errno
 import logging
 import os
 import subprocess
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from io import IOBase
 from platform import system
 from subprocess import PIPE
 from time import sleep
-from typing import IO
-from typing import Any
-from typing import List
-from typing import Mapping
-from typing import Optional
-from typing import Union
-from typing import cast
+from typing import IO, Any, List, Mapping, Optional, Union, cast
 from urllib import request
 from urllib.error import URLError
 
@@ -55,11 +48,11 @@ class Service(ABC):
 
     def __init__(
         self,
-        executable_path: str = None,
+        executable_path: Optional[str] = None,
         port: int = 0,
-        log_output: SubprocessStdAlias = None,
+        log_output: Optional[SubprocessStdAlias] = None,
         env: Optional[Mapping[Any, Any]] = None,
-        driver_path_env_key: str = None,
+        driver_path_env_key: Optional[str] = None,
         **kwargs,
     ) -> None:
         if isinstance(log_output, str):
@@ -152,12 +145,13 @@ class Service(ABC):
             elif isinstance(self.log_output, int):
                 os.close(self.log_output)
 
-        if self.process is not None:
+        if self.process is not None and self.process.poll() is None:
             try:
                 self.send_remote_shutdown_command()
             except TypeError:
                 pass
-            self._terminate_process()
+            finally:
+                self._terminate_process()
 
     def _terminate_process(self) -> None:
         """Terminate the child process.
