@@ -22,6 +22,7 @@ import warnings
 from base64 import b64encode
 from typing import Optional
 from urllib import parse
+from urllib.parse import urlparse
 
 import urllib3
 
@@ -125,6 +126,15 @@ remote_commands = {
     Command.GET_DOWNLOADABLE_FILES: ("GET", "/session/$sessionId/se/files"),
     Command.DOWNLOAD_FILE: ("POST", "/session/$sessionId/se/files"),
     Command.DELETE_DOWNLOADABLE_FILES: ("DELETE", "/session/$sessionId/se/files"),
+    # Federated Credential Management (FedCM)
+    Command.GET_FEDCM_TITLE: ("GET", "/session/$sessionId/fedcm/gettitle"),
+    Command.GET_FEDCM_DIALOG_TYPE: ("GET", "/session/$sessionId/fedcm/getdialogtype"),
+    Command.GET_FEDCM_ACCOUNT_LIST: ("GET", "/session/$sessionId/fedcm/accountlist"),
+    Command.CLICK_FEDCM_DIALOG_BUTTON: ("POST", "/session/$sessionId/fedcm/clickdialogbutton"),
+    Command.CANCEL_FEDCM_DIALOG: ("POST", "/session/$sessionId/fedcm/canceldialog"),
+    Command.SELECT_FEDCM_ACCOUNT: ("POST", "/session/$sessionId/fedcm/selectaccount"),
+    Command.SET_FEDCM_DELAY: ("POST", "/session/$sessionId/fedcm/setdelayenabled"),
+    Command.RESET_FEDCM_COOLDOWN: ("POST", "/session/$sessionId/fedcm/resetcooldown"),
 }
 
 
@@ -142,13 +152,9 @@ class RemoteConnection:
 
     import certifi
 
-    _timeout = (
-        float(os.getenv("GLOBAL_DEFAULT_TIMEOUT", str(socket.getdefaulttimeout())))
-        if os.getenv("GLOBAL_DEFAULT_TIMEOUT") is not None
-        else socket.getdefaulttimeout()
-    )
+    _timeout = socket.getdefaulttimeout()
     _ca_certs = os.getenv("REQUESTS_CA_BUNDLE") if "REQUESTS_CA_BUNDLE" in os.environ else certifi.where()
-    _client_config: ClientConfig = None
+    _client_config: Optional[ClientConfig] = None
 
     system = platform.system().lower()
     if system == "darwin":
@@ -158,6 +164,10 @@ class RemoteConnection:
     extra_headers = None
     user_agent = f"selenium/{__version__} (python {system})"
 
+    @property
+    def client_config(self):
+        return self._client_config
+
     @classmethod
     def get_timeout(cls):
         """:Returns:
@@ -166,7 +176,7 @@ class RemoteConnection:
         Remote Connection
         """
         warnings.warn(
-            "get_timeout() in RemoteConnection is deprecated, get timeout from ClientConfig instance instead",
+            "get_timeout() in RemoteConnection is deprecated, get timeout from client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -180,7 +190,7 @@ class RemoteConnection:
             - timeout - timeout value for http requests in seconds
         """
         warnings.warn(
-            "set_timeout() in RemoteConnection is deprecated, set timeout to ClientConfig instance in constructor instead",
+            "set_timeout() in RemoteConnection is deprecated, set timeout in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -190,7 +200,7 @@ class RemoteConnection:
     def reset_timeout(cls):
         """Reset the http request timeout to socket._GLOBAL_DEFAULT_TIMEOUT."""
         warnings.warn(
-            "reset_timeout() in RemoteConnection is deprecated, use reset_timeout() in ClientConfig instance instead",
+            "reset_timeout() in RemoteConnection is deprecated, use reset_timeout() in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -205,7 +215,7 @@ class RemoteConnection:
         REQUESTS_CA_BUNDLE env variable if set.
         """
         warnings.warn(
-            "get_certificate_bundle_path() in RemoteConnection is deprecated, get ca_certs from ClientConfig instance instead",
+            "get_certificate_bundle_path() in RemoteConnection is deprecated, get ca_certs from client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -221,7 +231,7 @@ class RemoteConnection:
             - path - path of a .pem encoded certificate chain.
         """
         warnings.warn(
-            "set_certificate_bundle_path() in RemoteConnection is deprecated, set ca_certs to ClientConfig instance in constructor instead",
+            "set_certificate_bundle_path() in RemoteConnection is deprecated, set ca_certs in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -243,6 +253,9 @@ class RemoteConnection:
         }
 
         if parsed_url.username:
+            warnings.warn(
+                "Embedding username and password in URL could be insecure, use ClientConfig instead", stacklevel=2
+            )
             base64string = b64encode(f"{parsed_url.username}:{parsed_url.password}".encode())
             headers.update({"Authorization": f"Basic {base64string.decode()}"})
 
@@ -255,16 +268,14 @@ class RemoteConnection:
         return headers
 
     def _identify_http_proxy_auth(self):
-        url = self._proxy_url
-        url = url[url.find(":") + 3 :]
-        return "@" in url and len(url[: url.find("@")]) > 0
+        parsed_url = urlparse(self._proxy_url)
+        if parsed_url.username and parsed_url.password:
+            return True
 
     def _separate_http_proxy_auth(self):
-        url = self._proxy_url
-        protocol = url[: url.find(":") + 3]
-        no_protocol = url[len(protocol) :]
-        auth = no_protocol[: no_protocol.find("@")]
-        proxy_without_auth = protocol + no_protocol[len(auth) + 1 :]
+        parsed_url = urlparse(self._proxy_url)
+        proxy_without_auth = f"{parsed_url.scheme}://{parsed_url.hostname}:{parsed_url.port}"
+        auth = f"{parsed_url.username}:{parsed_url.password}"
         return proxy_without_auth, auth
 
     def _get_connection_manager(self):
@@ -312,38 +323,40 @@ class RemoteConnection:
         RemoteConnection._timeout = self._client_config.timeout
         RemoteConnection._ca_certs = self._client_config.ca_certs
         RemoteConnection._client_config = self._client_config
+        RemoteConnection.extra_headers = self._client_config.extra_headers or RemoteConnection.extra_headers
+        RemoteConnection.user_agent = self._client_config.user_agent or RemoteConnection.user_agent
 
         if remote_server_addr:
             warnings.warn(
-                "setting remote_server_addr in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting remote_server_addr in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if not keep_alive:
             warnings.warn(
-                "setting keep_alive in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting keep_alive in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if ignore_certificates:
             warnings.warn(
-                "setting ignore_certificates in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting ignore_certificates in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if init_args_for_pool_manager:
             warnings.warn(
-                "setting init_args_for_pool_manager in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting init_args_for_pool_manager in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if ignore_proxy:
             warnings.warn(
-                "setting ignore_proxy in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting ignore_proxy in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
