@@ -27,35 +27,32 @@ import types
 import warnings
 import zipfile
 from abc import ABCMeta
-from base64 import b64decode
-from base64 import urlsafe_b64encode
-from contextlib import asynccontextmanager
-from contextlib import contextmanager
+from base64 import b64decode, urlsafe_b64encode
+from contextlib import asynccontextmanager, contextmanager
 from importlib import import_module
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Type
-from typing import Union
+from typing import Any, Dict, List, Optional, Type, Union
 
-from selenium.common.exceptions import InvalidArgumentException
-from selenium.common.exceptions import JavascriptException
-from selenium.common.exceptions import NoSuchCookieException
-from selenium.common.exceptions import NoSuchElementException
-from selenium.common.exceptions import WebDriverException
+from selenium.common.exceptions import (
+    InvalidArgumentException,
+    JavascriptException,
+    NoSuchCookieException,
+    NoSuchElementException,
+    WebDriverException,
+)
 from selenium.webdriver.common.bidi.browser import Browser
 from selenium.webdriver.common.bidi.browsing_context import BrowsingContext
 from selenium.webdriver.common.bidi.network import Network
 from selenium.webdriver.common.bidi.script import Script
 from selenium.webdriver.common.bidi.session import Session
+from selenium.webdriver.common.bidi.storage import Storage
+from selenium.webdriver.common.bidi.webextension import WebExtension
 from selenium.webdriver.common.by import By
-from selenium.webdriver.common.options import ArgOptions
-from selenium.webdriver.common.options import BaseOptions
+from selenium.webdriver.common.options import ArgOptions, BaseOptions
 from selenium.webdriver.common.print_page_options import PrintOptions
 from selenium.webdriver.common.timeouts import Timeouts
-from selenium.webdriver.common.virtual_authenticator import Credential
-from selenium.webdriver.common.virtual_authenticator import VirtualAuthenticatorOptions
 from selenium.webdriver.common.virtual_authenticator import (
+    Credential,
+    VirtualAuthenticatorOptions,
     required_virtual_authenticator,
 )
 from selenium.webdriver.support.relative_locator import RelativeBy
@@ -66,8 +63,7 @@ from .client_config import ClientConfig
 from .command import Command
 from .errorhandler import ErrorHandler
 from .fedcm import FedCM
-from .file_detector import FileDetector
-from .file_detector import LocalFileDetector
+from .file_detector import FileDetector, LocalFileDetector
 from .locator_converter import LocatorConverter
 from .mobile import Mobile
 from .remote_connection import RemoteConnection
@@ -215,7 +211,8 @@ class WebDriver(BaseWebDriver):
         keep_alive : bool (Deprecated)
             - Whether to configure remote_connection.RemoteConnection to use HTTP keep-alive. Defaults to True.
         file_detector : object or None
-            - Pass a custom file detector object during instantiation. If None, the default LocalFileDetector() will be used.
+            - Pass a custom file detector object during instantiation. If None, the default
+                LocalFileDetector() will be used.
         options : options.Options
             - Instance of a driver options.Options class.
         locator_converter : object or None
@@ -266,6 +263,8 @@ class WebDriver(BaseWebDriver):
         self._browser = None
         self._bidi_session = None
         self._browsing_context = None
+        self._storage = None
+        self._webextension = None
 
     def __repr__(self):
         return f'<{type(self).__module__}.{type(self).__name__} (session="{self.session_id}")>'
@@ -415,12 +414,12 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.execute_cdp_cmd('Network.getResponseBody', {'requestId': requestId})
+        >>> driver.execute_cdp_cmd("Network.getResponseBody", {"requestId": requestId})
 
         """
         return self.execute("executeCdpCommand", {"cmd": cmd, "params": cmd_args})["value"]
 
-    def execute(self, driver_command: str, params: dict = None) -> dict:
+    def execute(self, driver_command: str, params: Optional[dict[str, Any]] = None) -> dict[str, Any]:
         """Sends a command to be executed by a command.CommandExecutor.
 
         Parameters:
@@ -478,7 +477,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> element = driver.find_element(By.ID, 'foo')
+        >>> element = driver.find_element(By.ID, "foo")
         >>> print(element.title())
         """
         return self.execute(Command.GET_TITLE).get("value", "")
@@ -516,7 +515,7 @@ class WebDriver(BaseWebDriver):
         """
         return list(self.pinned_scripts)
 
-    def execute_script(self, script, *args):
+    def execute_script(self, script: str, *args):
         """Synchronously Executes JavaScript in the current window/frame.
 
         Parameters:
@@ -531,9 +530,7 @@ class WebDriver(BaseWebDriver):
         --------
         >>> input_id = "username"
         >>> input_value = "test_user"
-        >>> driver.execute_script(
-        ...     "document.getElementById(arguments[0]).value = arguments[1];", input_id, input_value
-        ... )
+        >>> driver.execute_script("document.getElementById(arguments[0]).value = arguments[1];", input_id, input_value)
         """
         if isinstance(script, ScriptKey):
             try:
@@ -682,11 +679,11 @@ class WebDriver(BaseWebDriver):
         >>> element = driver.switch_to.active_element
         >>> alert = driver.switch_to.alert
         >>> driver.switch_to.default_content()
-        >>> driver.switch_to.frame('frame_name')
+        >>> driver.switch_to.frame("frame_name")
         >>> driver.switch_to.frame(1)
         >>> driver.switch_to.frame(driver.find_elements(By.TAG_NAME, "iframe")[0])
         >>> driver.switch_to.parent_frame()
-        >>> driver.switch_to.window('main')
+        >>> driver.switch_to.window("main")
         """
         return self._switch_to
 
@@ -739,7 +736,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> cookie = driver.get_cookie('my_cookie')
+        >>> cookie = driver.get_cookie("my_cookie")
         """
         if not name or name.isspace():
             raise ValueError("Cookie name cannot be empty")
@@ -755,7 +752,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.delete_cookie('my_cookie')
+        >>> driver.delete_cookie("my_cookie")
         """
 
         # firefox deletes all cookies when "" is passed as name
@@ -784,10 +781,10 @@ class WebDriver(BaseWebDriver):
 
         Examples:
         --------
-        >>> driver.add_cookie({'name' : 'foo', 'value' : 'bar'})
-        >>> driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/'})
-        >>> driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/', 'secure' : True})
-        >>> driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'sameSite' : 'Strict'})
+        >>> driver.add_cookie({"name": "foo", "value": "bar"})
+        >>> driver.add_cookie({"name": "foo", "value": "bar", "path": "/"})
+        >>> driver.add_cookie({"name": "foo", "value": "bar", "path": "/", "secure": True})
+        >>> driver.add_cookie({"name": "foo", "value": "bar", "sameSite": "Strict"})
         """
         if "sameSite" in cookie_dict:
             assert cookie_dict["sameSite"] in ["Strict", "Lax", "None"]
@@ -977,7 +974,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.get_screenshot_as_file('/Screenshots/foo.png')
+        >>> driver.get_screenshot_as_file("/Screenshots/foo.png")
         """
         if not str(filename).lower().endswith(".png"):
             warnings.warn(
@@ -1008,7 +1005,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.save_screenshot('/Screenshots/foo.png')
+        >>> driver.save_screenshot("/Screenshots/foo.png")
         """
         return self.get_screenshot_as_file(filename)
 
@@ -1044,7 +1041,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.set_window_size(800,600)
+        >>> driver.set_window_size(800, 600)
         """
         self._check_if_window_handle_is_current(windowHandle)
         self.set_window_rect(width=int(width), height=int(height))
@@ -1078,7 +1075,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.set_window_position(0,0)
+        >>> driver.set_window_position(0, 0)
         """
         self._check_if_window_handle_is_current(windowHandle)
         return self.set_window_rect(x=int(x), y=int(y))
@@ -1174,7 +1171,7 @@ class WebDriver(BaseWebDriver):
 
         Example:
         --------
-        >>> driver.orientation = 'landscape'
+        >>> driver.orientation = "landscape"
         """
         allowed_values = ["LANDSCAPE", "PORTRAIT"]
         if value.upper() in allowed_values:
@@ -1317,6 +1314,53 @@ class WebDriver(BaseWebDriver):
 
         return self._browsing_context
 
+    @property
+    def storage(self):
+        """Returns a storage module object for BiDi storage commands.
+
+        Returns:
+        --------
+        Storage: an object containing access to BiDi storage commands.
+
+        Examples:
+        ---------
+        >>> cookie_filter = CookieFilter(name="example")
+        >>> result = driver.storage.get_cookies(filter=cookie_filter)
+        >>> driver.storage.set_cookie(cookie=PartialCookie(
+                "name", BytesValue(BytesValue.TYPE_STRING, "value"), "domain")
+            )
+        >>> driver.storage.delete_cookies(filter=CookieFilter(name="example"))
+        """
+        if not self._websocket_connection:
+            self._start_bidi()
+
+        if self._storage is None:
+            self._storage = Storage(self._websocket_connection)
+
+        return self._storage
+
+    @property
+    def webextension(self):
+        """Returns a webextension module object for BiDi webextension commands.
+
+        Returns:
+        --------
+        WebExtension: an object containing access to BiDi webextension commands.
+
+        Examples:
+        ---------
+        >>> extension_path = "/path/to/extension"
+        >>> extension_result = driver.webextension.install(path=extension_path)
+        >>> driver.webextension.uninstall(extension_result)
+        """
+        if not self._websocket_connection:
+            self._start_bidi()
+
+        if self._webextension is None:
+            self._webextension = WebExtension(self._websocket_connection)
+
+        return self._webextension
+
     def _get_cdp_details(self):
         import json
 
