@@ -17,22 +17,17 @@
 
 import re
 from collections.abc import Iterable
-from typing import Any
-from typing import Callable
-from typing import List
-from typing import Literal
-from typing import Tuple
-from typing import TypeVar
-from typing import Union
+from typing import Any, Callable, List, Literal, Tuple, TypeVar, Union
 
-from selenium.common.exceptions import NoAlertPresentException
-from selenium.common.exceptions import NoSuchElementException
-from selenium.common.exceptions import NoSuchFrameException
-from selenium.common.exceptions import StaleElementReferenceException
-from selenium.common.exceptions import WebDriverException
+from selenium.common.exceptions import (
+    NoAlertPresentException,
+    NoSuchElementException,
+    NoSuchFrameException,
+    StaleElementReferenceException,
+    WebDriverException,
+)
 from selenium.webdriver.common.alert import Alert
-from selenium.webdriver.remote.webdriver import WebDriver
-from selenium.webdriver.remote.webdriver import WebElement
+from selenium.webdriver.remote.webdriver import WebDriver, WebElement
 
 """
  * Canned "Expected Conditions" which are generally useful within webdriver
@@ -102,8 +97,7 @@ def presence_of_element_located(locator: Tuple[str, str]) -> Callable[[WebDriver
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> element = WebDriverWait(driver, 10).until(
-    ... EC.presence_of_element_located((By.NAME, "q")))
+    >>> element = WebDriverWait(driver, 10).until(EC.presence_of_element_located((By.NAME, "q")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -215,8 +209,7 @@ def visibility_of_element_located(
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> element = WebDriverWait(driver, 10).until(
-    ... EC.visibility_of_element_located((By.NAME, "q")))
+    >>> element = WebDriverWait(driver, 10).until(EC.visibility_of_element_located((By.NAME, "q")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -246,8 +239,7 @@ def visibility_of(element: WebElement) -> Callable[[Any], Union[Literal[False],
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> element = WebDriverWait(driver, 10).until(
-    ... EC.visibility_of(driver.find_element(By.NAME, "q")))
+    >>> element = WebDriverWait(driver, 10).until(EC.visibility_of(driver.find_element(By.NAME, "q")))
 
     Notes:
     ------
@@ -298,8 +290,7 @@ def presence_of_all_elements_located(locator: Tuple[str, str]) -> Callable[[WebD
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> elements = WebDriverWait(driver, 10).until(
-    ... EC.presence_of_all_elements_located((By.CLASS_NAME, "foo")))
+    >>> elements = WebDriverWait(driver, 10).until(EC.presence_of_all_elements_located((By.CLASS_NAME, "foo")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -326,8 +317,7 @@ def visibility_of_any_elements_located(locator: Tuple[str, str]) -> Callable[[We
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> elements = WebDriverWait(driver, 10).until(
-    ... EC.visibility_of_any_elements_located((By.CLASS_NAME, "foo")))
+    >>> elements = WebDriverWait(driver, 10).until(EC.visibility_of_any_elements_located((By.CLASS_NAME, "foo")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -357,8 +347,7 @@ def visibility_of_all_elements_located(
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> elements = WebDriverWait(driver, 10).until(
-    ... EC.visibility_of_all_elements_located((By.CLASS_NAME, "foo")))
+    >>> elements = WebDriverWait(driver, 10).until(EC.visibility_of_all_elements_located((By.CLASS_NAME, "foo")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -395,7 +384,8 @@ def text_to_be_present_in_element(locator: Tuple[str, str], text_: str) -> Calla
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_text_in_element = WebDriverWait(driver, 10).until(
-    ... EC.text_to_be_present_in_element((By.CLASS_NAME, "foo"), "bar"))
+            EC.text_to_be_present_in_element((By.CLASS_NAME, "foo"), "bar")
+        )
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -431,7 +421,8 @@ def text_to_be_present_in_element_value(
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_text_in_element_value = WebDriverWait(driver, 10).until(
-    ... EC.text_to_be_present_in_element_value((By.CLASS_NAME, "foo"), "bar"))
+    ...     EC.text_to_be_present_in_element_value((By.CLASS_NAME, "foo"), "bar")
+    ... )
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -469,8 +460,8 @@ def text_to_be_present_in_element_attribute(
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_text_in_element_attribute = WebDriverWait(driver, 10).until(
-    ... EC.text_to_be_present_in_element_attribute((By.CLASS_NAME, "foo"),
-    ... "bar", "baz"))
+    ...     EC.text_to_be_present_in_element_attribute((By.CLASS_NAME, "foo"), "bar", "baz")
+    ... )
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -504,8 +495,7 @@ def frame_to_be_available_and_switch_to_it(
     --------
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> WebDriverWait(driver, 10).until(
-    ... EC.frame_to_be_available_and_switch_to_it("frame_name"))
+    >>> WebDriverWait(driver, 10).until(EC.frame_to_be_available_and_switch_to_it("frame_name"))
 
     Notes:
     ------
@@ -546,8 +536,7 @@ def invisibility_of_element_located(
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_invisible = WebDriverWait(driver, 10).until(
-    ... EC.invisibility_of_element_located((By.CLASS_NAME, "foo")))
+    >>> is_invisible = WebDriverWait(driver, 10).until(EC.invisibility_of_element_located((By.CLASS_NAME, "foo")))
 
     Notes:
     ------
@@ -596,7 +585,8 @@ def invisibility_of_element(
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_invisible_or_not_present = WebDriverWait(driver, 10).until(
-    ... EC.invisibility_of_element(driver.find_element(By.CLASS_NAME, "foo")))
+    ...     EC.invisibility_of_element(driver.find_element(By.CLASS_NAME, "foo"))
+    ... )
     """
     return invisibility_of_element_located(element)
 
@@ -621,8 +611,7 @@ def element_to_be_clickable(
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> element = WebDriverWait(driver, 10).until(
-    ... EC.element_to_be_clickable((By.CLASS_NAME, "foo")))
+    >>> element = WebDriverWait(driver, 10).until(EC.element_to_be_clickable((By.CLASS_NAME, "foo")))
     """
 
     # renamed argument to 'mark', to indicate that both locator
@@ -656,8 +645,7 @@ def staleness_of(element: WebElement) -> Callable[[Any], bool]:
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_element_stale = WebDriverWait(driver, 10).until(
-    ... EC.staleness_of(driver.find_element(By.CLASS_NAME, "foo")))
+    >>> is_element_stale = WebDriverWait(driver, 10).until(EC.staleness_of(driver.find_element(By.CLASS_NAME, "foo")))
     """
 
     def _predicate(_):
@@ -688,8 +676,9 @@ def element_to_be_selected(element: WebElement) -> Callable[[Any], bool]:
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_selected = WebDriverWait(driver, 10).until(
-    ... EC.element_to_be_selected(driver.find_element(By.CLASS_NAME, "foo")))
+    >>> is_selected = WebDriverWait(driver, 10).until(EC.element_to_be_selected(driver.find_element(
+            By.CLASS_NAME, "foo"))
+        )
     """
 
     def _predicate(_):
@@ -715,8 +704,7 @@ def element_located_to_be_selected(locator: Tuple[str, str]) -> Callable[[WebDri
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_selected = WebDriverWait(driver, 10).until(
-    ... EC.element_located_to_be_selected((By.CLASS_NAME, "foo")))
+    >>> is_selected = WebDriverWait(driver, 10).until(EC.element_located_to_be_selected((By.CLASS_NAME, "foo")))
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -744,7 +732,8 @@ def element_selection_state_to_be(element: WebElement, is_selected: bool) -> Cal
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_selected = WebDriverWait(driver, 10).until(
-    ... EC.element_selection_state_to_be(driver.find_element(By.CLASS_NAME, "foo"), True))
+    ...     EC.element_selection_state_to_be(driver.find_element(By.CLASS_NAME, "foo"), True)
+    ... )
     """
 
     def _predicate(_):
@@ -774,8 +763,9 @@ def element_located_selection_state_to_be(
     >>> from selenium.webdriver.common.by import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_selected = WebDriverWait(driver, 10).until(
-    ... EC.element_located_selection_state_to_be((By.CLASS_NAME, "foo"), True))
+    >>> is_selected = WebDriverWait(driver, 10).until(EC.element_located_selection_state_to_be(
+            (By.CLASS_NAME, "foo"), True)
+        )
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -804,8 +794,7 @@ def number_of_windows_to_be(num_windows: int) -> Callable[[WebDriver], bool]:
     --------
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_number_of_windows = WebDriverWait(driver, 10).until(
-    ... EC.number_of_windows_to_be(2))
+    >>> is_number_of_windows = WebDriverWait(driver, 10).until(EC.number_of_windows_to_be(2))
     """
 
     def _predicate(driver: WebDriver):
@@ -832,8 +821,7 @@ def new_window_is_opened(current_handles: List[str]) -> Callable[[WebDriver], bo
     >>> from selenium.webdriver.support.ui import By
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
-    >>> is_new_window_opened = WebDriverWait(driver, 10).until(
-    ... EC.new_window_is_opened(driver.window_handles))
+    >>> is_new_window_opened = WebDriverWait(driver, 10).until(EC.new_window_is_opened(driver.window_handles))
     """
 
     def _predicate(driver: WebDriver):
@@ -891,7 +879,8 @@ def element_attribute_to_include(locator: Tuple[str, str], attribute_: str) -> C
     >>> from selenium.webdriver.support.ui import WebDriverWait
     >>> from selenium.webdriver.support import expected_conditions as EC
     >>> is_attribute_in_element = WebDriverWait(driver, 10).until(
-    ... EC.element_attribute_to_include((By.CLASS_NAME, "foo"), "bar"))
+    ...     EC.element_attribute_to_include((By.CLASS_NAME, "foo"), "bar")
+    ... )
     """
 
     def _predicate(driver: WebDriverOrWebElement):
@@ -945,7 +934,7 @@ def any_of(*expected_conditions: Callable[[D], T]) -> Callable[[D], Union[Litera
 
 
 def all_of(
-    *expected_conditions: Callable[[D], Union[T, Literal[False]]]
+    *expected_conditions: Callable[[D], Union[T, Literal[False]]],
 ) -> Callable[[D], Union[List[T], Literal[False]]]:
     """An expectation that all of multiple expected conditions is true.
 
